@@ -6,7 +6,7 @@ our $AUTHORITY = 'cpan:GENE';
 use strict;
 use warnings;
 
-our $VERSION = '0.2200';
+our $VERSION = '0.2201';
 
 use Carp;
 use Algorithm::Combinatorics qw( permutations );
@@ -497,7 +497,7 @@ Game::Theory::TwoPersonMatrix - Analyze a 2 person matrix game
 
 =head1 VERSION
 
-version 0.2200
+version 0.2201
 
 =head1 SYNOPSIS
 
@@ -513,11 +513,11 @@ version 0.2200
  $g->row_reduce();
  $g->col_reduce();
  my $player = 1;
- my $s = $g->saddlepoint();
- my $o = $g->oddments();
- my $e = $g->expected_payoff();
- my $c = $g->counter_strategy($player);
- my $p = $g->play();
+ my $x = $g->saddlepoint();
+ $x = $g->oddments();
+ $x = $g->expected_payoff();
+ $x = $g->counter_strategy($player);
+ $x = $g->play();
 
  $g = Game::Theory::TwoPersonMatrix->new(
     1 => { 1 => 0.1, 2 => 0.2, 3 => 0.7 },
@@ -532,12 +532,12 @@ version 0.2200
                  [3,4,4,1],
                  [5,6,8,2] ],
  );
- my $t = $g->mm_tally();
- my $m = $g->pareto_optimal();
- my $n = $g->nash();
- $e = $g->expected_payoff();
- $c = $g->counter_strategy($player);
- $p = $g->play();
+ $x = $g->mm_tally();
+ $x = $g->pareto_optimal();
+ $x = $g->nash();
+ $x = $g->expected_payoff();
+ $x = $g->counter_strategy($player);
+ $x = $g->play();
 
 =head1 DESCRIPTION
 
@@ -562,13 +562,13 @@ and T > R > P > S is:
       \    | Cooperate | Defect
  Blue   \  |           |
  --------------------------------
-           | \   R2    | \   T2
- Cooperate |   \       |   \
-           | R1  \     | S1  \
+           |  \   R2   |  \   T2
+ Cooperate |    \      |    \
+           | R1   \    | S1   \
  --------------------------------
-           | \   S2    | \   P2
- Defect    |   \       |   \
-           | T1  \     | P1  \
+           |  \   S2   |  \   P2
+ Defect    |    \      |    \
+           | T1   \    | P1   \
 
 And in this implementation that would be:
 
@@ -616,7 +616,7 @@ this is a single payoff list.  For non-zero-sum games this is given as two lists
 
 =head2 expected_payoff()
 
- $e = $g->expected_payoff();
+ $x = $g->expected_payoff();
 
 Return the expected payoff value of a game.
 
@@ -627,7 +627,7 @@ Return the expected payoff value of a game.
     2 => { 1 => 1, 2 => 0 },
     payoff => [ ['a','b'], ['c','d'] ]
  );
- $s = $g->s_expected_payoff();
+ $x = $g->s_expected_payoff();
 
 Return the symbolic expected payoff expression for a non-numeric game.
 
@@ -636,14 +636,14 @@ F<eg/> examples.
 
 =head2 counter_strategy()
 
- $c = $g->counter_strategy($player);
+ $x = $g->counter_strategy($player);
 
 Return the expected payoff, for a given player, of either a zero-sum or
 non-zero-sum game, given pure opponent strategies.
 
 =head2 saddlepoint()
 
- $s = $g->saddlepoint;
+ $x = $g->saddlepoint;
 
 Return the saddlepoint of a zero-sum game, or C<undef> if there is none.
 
@@ -651,7 +651,7 @@ A saddlepoint is simultaneously minimum for its row and maximum for its column.
 
 =head2 oddments()
 
- $o = $g->oddments();
+ $x = $g->oddments();
 
 Return each player's "oddments" for a 2x2 zero-sum game with no saddlepoint.
 
@@ -671,20 +671,20 @@ and their associated opponent strategies.
 
 =head2 mm_tally()
 
- $t = $g->mm_tally();
+ $x = $g->mm_tally();
 
 For zero-sum games, return the maximum of row minimums and the minimum of column
 maximums.  For non-zero-sum games, return the maximum of row and column minimums.
 
 =head2 pareto_optimal()
 
- $m = $g->pareto_optimal();
+ $x = $g->pareto_optimal();
 
 Return the Pareto optimal outcomes for a non-zero-sum game.
 
 =head2 nash()
 
- $n = $g->nash();
+ $x = $g->nash();
 
 Identify the Nash equilibria in a non-zero-sum game.
 
@@ -693,8 +693,8 @@ for its row.
 
 =head2 play()
 
- $p = $g->play();
- $p = $g->play(%strategies);
+ $x = $g->play();
+ $x = $g->play(%strategies);
 
 Return a single outcome for a zero-sum game, or a pair for a non-zero-sum game
 as a hashref keyed by each strategy chosen and with values of the payoff(s)
